@@ -3,12 +3,15 @@ import time
 import warnings
 import re
 
+
 class InvalidInputError(Exception):
     pass
 
+
 class UnknownDateFormatError(InvalidInputError):
     pass
 
+
 def crossbar(date):
     """
     :param date: yyyymmdd:int
@@ -25,6 +28,8 @@ def format_match(date):
     _ = str(date)
     if re.match(r"\d{8}$", _):
         return "%Y%m%d"
+    elif re.match(r"\d{12}$", _):
+        return "%Y%m%d%H%M"
     elif re.match(r"\d{14}$", _):
         return "%Y%m%d%H%M%S"
     elif re.match(r"\d{4}-\d{2}-\d{2}$", _):
@@ -32,7 +37,7 @@ def format_match(date):
     elif re.match(r"\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$", _):
         return "%Y-%m-%d %H:%M:%S"
     else:
-        raise UnknownDateFormatError("valid date formats are %Y%m%d, %Y%m%d%H%M%S, %Y-%m-%d, %Y-%m-%d %H:%M:%S")
+        raise UnknownDateFormatError("valid formats: %Y%m%d, %Y%m%d%H%M, %Y%m%d%H%M%S, %Y-%m-%d, %Y-%m-%d %H:%M:%S")
 
 
 def strptime(date):
@@ -45,15 +50,6 @@ def strptime(date):
     return datetime.datetime.strptime(_, format_match(_))
 
 
-def strftime(date, format="%Y-%m-%d %H:%M:%S"):
-    """
-    :param date: datetime.datetime object
-    :param format:
-    :return: formated datetime str
-    """
-    return date.strftime(format)
-
-
 def stamp():
     """
     :return: now() in "%Y%m%d%H%M%S":str
@@ -67,16 +63,16 @@ def interval(start, end):
     :param end: %Y-%m-%d[.*]:str or yyyymmdd:int
     :return:days:int between input dates
     """
-    return (strptime(end)-strptime(start)).days
+    return (strptime(end) - strptime(start)).days
 
 
-def move(date,days=0):
+def move(date, days=0):
     """
     :param date: formated str('yyyy-mm-dd','yyyymmdd','yyyy-mm-dd H:M:S'etc) or int(yyyymmdd,yyyymmddHMS)
     :param days: int
     :return: datetime.datetime object
     """
-    return strptime(date)+datetime.timedelta(days=days)
+    return strptime(date) + datetime.timedelta(days=days)
 
 
 def add_days(date, n):
@@ -124,7 +120,7 @@ if __name__ == "__main__":
 
     print(format(strptime("2020-03-02")))
 
-    print(move(strptime("2020-03-02"),-28))
+    print(move(strptime("2020-03-02"), -28))
 
     print(stamp())
     print(interval("2020-01-16", "2020-01-17"))
